from fastapi import APIRouter, HTTPException, status, Depends
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.contactform import ContactFormCreate, ContactFormSchema
from helpers.contactform_helpers import validate_contact_form_data, create_contact_form, format_validation_error_response, send_notification_email

router = APIRouter()

@router.post("/names", status_code=status.HTTP_201_CREATED, response_model=ContactFormSchema)
async def submit_contact_form(
    form_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    """
    Handle contact form submissions with validation for required fields and email format.
    """
    # Validate the form data
    validation_errors = validate_contact_form_data(form_data.dict())
    
    # If there are validation errors, return a 400 response with details
    if validation_errors:
        error_response = format_validation_error_response(validation_errors)
        raise HTTPException(
            status_code=status.HTTP_400_BAD_REQUEST,
            detail=error_response
        )
    
    # Create the contact form entry in the database
    contact_form = create_contact_form(db=db, form_data=form_data)
    
    # Send notification email (in a real application, this might be done asynchronously)
    send_notification_email(contact_form)
    
    return contact_form